import httpRequest from '@/utils/axios'

/**
 * 获取应用列表
 */
export function getAppList(params) {
  return httpRequest.get('/api/qbs/admin/v1/questions', { params })
}
/**
 * 获取题目分类树形结构
 */
export function getQuestionCategory(params) {
  return httpRequest.get(`/api/qbs/admin/v1/question-category/tree/${params}`)
}
/**
 * 添加试题分类
 */
export function addQuestionCategory(data) {
  return httpRequest.post('/api/qbs/admin/v1/question-category', data)
}
/**
 * 更新应用
 */
export function updateQuestionCategory(id, data) {
  return httpRequest.put(`/api/qbs/admin/v1/question-category/${id}`, data)
}
/**
 * 知识点标签搜索
 */
export function searchTag(params) {
  return httpRequest.get('/api/qbs/admin/v1/knowledge-point/search/x1', { params })
}
/**
 * 新建试题
 */
export function addQuestion(data) {
  return httpRequest.post('/api/qbs/admin/v1/question', data)
}

/**
 * 获取应用详情
 */
export function getApp(id, params) {
  return httpRequest.get(`/api/permissions/admin/v1/${id}/application`, { params })
}
/**
 * 创建应用
 */
export function createApp(data) {
  return httpRequest.post('/api/permissions/admin/v1/application', data)
}
/**
 * 更新应用
 */
export function updateApp(id, data) {
  return httpRequest.put(`/api/permissions/admin/v1/${id}/application`, data)
}
/**
 * 删除应用
 */
export function deleteApp(id, data) {
  return httpRequest.delete(`/api/permissions/admin/v1/${id}/application`, data)
}
/**
 * 更新应用签名秘钥
 */
export function updateAppSecretKey(id, data) {
  return httpRequest.patch(`/api/permissions/admin/v1/${id}/application/secret-key`, data)
}

/**
 * 获取应用管理员
 */
export function getAppAdminUsers(params) {
  return httpRequest.get(`/api/permissions/admin/v1/${params.app_id}/application/assign/app-users`, { params })
}

/**
 * 删除应用管理员
 */
export function deleteAppAdminUsers(appid, data) {
  return httpRequest.post(`/api/permissions/admin/v1/${appid}/application/assign/remove-app-users`, data)
}

/**
 * 创建成员
 */
export function createUser(appid, data) {
  return httpRequest.post(`/api/permissions/admin/v1/${appid}/application/user`, data)
}

/**
 * 创建应用管理员
 */
export function createAppAdminUsers(appid, data) {
  return httpRequest.post(`/api/permissions/admin/v1/${appid}/application/assign/users-to-app`, data)
}

/**
 * 获取事件列表
 */
export function getEventList(params) {
  return httpRequest.get(`/api/permissions/admin/v1/${params.app_id}/events`, { params })
}
/**
 * 创建事件
 */
export function createEvent(appid, data) {
  return httpRequest.post(`/api/permissions/admin/v1/${appid}/event/create`, data)
}
/**
 * 更新事件
 */
export function updateEvent(id, data) {
  return httpRequest.put(`/api/permissions/admin/v1/event/${id}/update`, data)
}
/**
 * 删除事件
 */
export function deleteEvents(data) {
  return httpRequest.post('/api/permissions/admin/v1/event/batch-delete', data)
}
/**
 * 获取事件详情
 */
export function getEvent(params) {
  return httpRequest.get(`/api/permissions/admin/v1/event/${params.id}/detail`, { params })
}
/**
 * 刷新事件token
 */
export function refreshEventToken(params) {
  return httpRequest.patch(`/api/permissions/admin/v1/event/${params.id}/refresh-token`, { params })
}
/**
 * 获取获取事件回调记录列表
 */
export function getEventRecordList(params) {
  return httpRequest.get(`/api/permissions/admin/v1/${params.app_id}/event/records`, { params })
}
